.. default-role:: literal

Functions
#########

Functions in manifest are used for:

- Transforming and validating data using `prepare` parameter.

- Describing database migration steps.


Using functions in Manifest
===========================


